# ###############################################################################
# 
# The folder accompanies the benchmark paper
# "Transfer and intercomparison of data-driven uncertainty 
# quantification methods for two-phase flow in carbon dioxide storage"
# by M. Köppel, F. Franzelin, I. Kröker, S. Oladyshkin, G. Santin and D. Wittwar.
# 
# This README file explains the structure of the associated data files in order
# to facilitate the reproducubility and/or a comparsion with other methods. 
# 
# Apart from the executables and its input file, the data is given in 
# .csv file format with headings of the different columns.
#
# ###############################################################################


### How to use the executable(s)

* 'prog':		Linux version
* 'win_prog.exe':	Windows version

Command Line Arguments

-h
	This option provides complete text instruction.

-MC<samples>
	Run the simulation only for the first <samples> parameter sets in the input
	file. Default setting '-MC1' runs the simulation for one parameter sets.

-mMC<snapshot>
	Write a snapshot for all <snapshot> number of simulations. Default setting
	is '-mMC0': run without snapshots.

-pfile<input>
	Input data file.

-path<path>
	Path for the output files. The output files have following structure:
	*_<number>.dat : x-coordinate | mean value
	*_v_<number>.dat : x-coordinate | variance
	*_S_<number>.dat : each line contains solutions for all spacial grid points for
	the corresponding line in the input file.

-allS
	This parameter switches the output for all parameter sets to 'on'. Default
	setting is 'off', which provides only the mean and variance over all parameter sets.

Example

./prog -pfile InputParameters.txt -path ./tmp/ -allS -MC 10


### 'InputParameters.txt'

Parameter file for the executables 'prog' and 'win_prog.exe' containing the distribution
of the parameters injection rate, residual saturation, relative permeability degree, 
and reservoir porosity based on 10,000 samples. 


### 'InputParameters.csv'

Contains the distribution of the uncertain parameters ...
    1) injection rate (ir),
    2) relative permeability degree (kd),
    3) reservoir porosity (po).
based on 10,000 samples. 


### 'MCrefs_MeanStd.csv'

Provides the results of the Monte Carlo reference solution for expectation/mean ('e..')
and standard deviation ('s..') of the quantity of interest over the spatial coordinate 
('x') for different uncertain injection rate ('eir'/'sir'), uncertain relative permeability 
degree ('ekd'/'skd'), uncertain reservoir porosity ('epo'/'spo') and uncertainty in all
three parameters ('eal'/'eal'). 


### 'aPCsols_MeanStd.csv'

Data file of the arbitary polynomial chaos method which provides the results of expectation/
mean ('e..') and standard deviation ('s..') of the quantity of interest over the spatial 
coordinate ('x') for different expansion orders ('..o..') and number of model runs ('..mr').


### 'aSGsols_MeanStd.csv'

Data file of the spatially adaptive spare grid method which provides the results of expectation/
mean ('e..') and standard deviation ('s..') of the quantity of interest over the spatial 
coordinate ('x') for different number of model runs ('.N..') in the case of boundary points ('..b')
and without boundary points but with modified basis ('..m').


### 'pGREEDYsols_MeanStd.csv'

Data file of the kernal greedy interpolation (reduced basis) method which provides the results 
of expectation/mean ('e..') and standard deviation ('s..') of the quantity of interest over 
the spatial coordinate ('x') for different number of model runs ('.N..') and shape parameters
controlling the kernel width ('..d..').


### 'HSGsols_MeanStd.csv'

Data file of the intrusive hybrid stochastic Galerkin method which provides the results 
of expectation/mean ('e..') and standard deviation ('s..') of the quantity of interest over 
the spatial coordinate ('x') for different bisection levels ('..Nr..') of the stochastic 
space and different polynomial order ('..Nr.'). The multiple usage of these two parameters
refers to the additional decomposition of the stochastic space, cf. manuscript.


### 'L2norm_mean_joint.csv' and 'L2norm_std_joint.csv'

Contain the absolute L2 errors for expectation/mean and standard deviation, respectively, 
of the quantity of interest ('y_..') over the number of model runs/number of stochastic elements
('x_...') for the corresponding method applied, namely
    1) arbitary polynomial chaos ('..aPC.'),
    2) spatially adaptive spare grid method ('..aSG.'),
    3) kernal greedy interpolation/reduced basis ('..RB.'),
    4) intrusive hybrid stochastic Galerkin ('..HSG.'),
depending on the specific parameters which characterize the different methods.

